#

##

###

    	stack
    		# nodes
    		# organisms

    	possibilities

    		systemd
    			apt install systemd -y
    			systemctl --version

    			[Unit]
    			Description=VV_turbo
    			After=network.target

    			[Service]
    			Type=simple
    			User=myuser
    			Group=mygroup
    			WorkingDirectory=/path/to/your/application
    			ExecStart=/path/to/your/application/my_script.py
    			Restart=always

    			[Install]
    			WantedBy=multi-user.target